@@ -24,8 +24,14 @@ TRANSLATION_FEED_ATOM = None
 
 PLUGINS = [
     "pelican.plugins.webassets",
+    "pelican.plugins.sitemap",
+    "voltaire.stats",
     "voltaire.wikilinks",
 ]
+SITEMAP = {
+    "format": "xml",
+    "exclude": ["search/"],
+}
 
 THEME = os.path.join(os.path.dirname(os.path.realpath(__file__)), "theme")
 THEME_STATIC_PATHS = [
@@ -42,7 +48,9 @@ if path.exists():
 MARKDOWN = {
     "extension_configs": {
         "voltaire.mermaid": {},
+        "plantuml_markdown": {},
         "markdown.extensions.extra": {},
+        "markdown.extensions.toc": {},
     },
     "output_format": "html5",
 }
